@@ -1,5 +1,5 @@
 package File::Format::CRD;
-$File::Format::CRD::VERSION = '0.2.0';
+$File::Format::CRD::VERSION = '0.2.1';
 use warnings;
 use strict;
 
@@ -21,7 +21,7 @@ File::Format::CRD - Distribution for reading the Windows CRD format.
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
@@ -88,37 +88,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-file-format-crd/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Format::CRD
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -136,14 +109,6 @@ L<https://metacpan.org/release/File-Format-CRD>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Format-CRD>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -152,22 +117,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Format-CRD>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Format-CRD>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Format-CRD>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -216,4 +165,25 @@ L<https://github.com/shlomif/perl-file-format-crd>
 
   git clone git://github.com/shlomif/perl-file-format-crd.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-file-format-crd/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
